@@ -1,56 +1,64 @@
-( cd opt/kde/lib ; rm -rf libartsc.so )
-( cd opt/kde/lib ; ln -sf libartsc.so.0.0.0 libartsc.so )
-( cd opt/kde/lib ; rm -rf libartsc.so.0 )
-( cd opt/kde/lib ; ln -sf libartsc.so.0.0.0 libartsc.so.0 )
-( cd opt/kde/lib ; rm -rf libartscbackend.so )
-( cd opt/kde/lib ; ln -sf libartscbackend.so.0.0.0 libartscbackend.so )
-( cd opt/kde/lib ; rm -rf libartscbackend.so.0 )
-( cd opt/kde/lib ; ln -sf libartscbackend.so.0.0.0 libartscbackend.so.0 )
-( cd opt/kde/lib ; rm -rf libartsdsp.so )
-( cd opt/kde/lib ; ln -sf libartsdsp.so.0.0.0 libartsdsp.so )
+( cd opt/kde/lib ; rm -rf libmcop.so )
+( cd opt/kde/lib ; ln -sf libmcop.so.1.0.0 libmcop.so )
 ( cd opt/kde/lib ; rm -rf libartsdsp.so.0 )
 ( cd opt/kde/lib ; ln -sf libartsdsp.so.0.0.0 libartsdsp.so.0 )
-( cd opt/kde/lib ; rm -rf libartsdsp_st.so )
-( cd opt/kde/lib ; ln -sf libartsdsp_st.so.0.0.0 libartsdsp_st.so )
-( cd opt/kde/lib ; rm -rf libartsdsp_st.so.0 )
-( cd opt/kde/lib ; ln -sf libartsdsp_st.so.0.0.0 libartsdsp_st.so.0 )
+( cd opt/kde/lib ; rm -rf libsoundserver_idl.so )
+( cd opt/kde/lib ; ln -sf libsoundserver_idl.so.1.0.0 libsoundserver_idl.so )
+( cd opt/kde/lib ; rm -rf libgmcop.so )
+( cd opt/kde/lib ; ln -sf libgmcop.so.1.0.0 libgmcop.so )
+( cd opt/kde/lib ; rm -rf libartscbackend.so.0 )
+( cd opt/kde/lib ; ln -sf libartscbackend.so.0.0.0 libartscbackend.so.0 )
 ( cd opt/kde/lib ; rm -rf libartsflow.so )
 ( cd opt/kde/lib ; ln -sf libartsflow.so.1.0.0 libartsflow.so )
 ( cd opt/kde/lib ; rm -rf libartsflow.so.1 )
 ( cd opt/kde/lib ; ln -sf libartsflow.so.1.0.0 libartsflow.so.1 )
-( cd opt/kde/lib ; rm -rf libartsflow_idl.so )
-( cd opt/kde/lib ; ln -sf libartsflow_idl.so.1.0.0 libartsflow_idl.so )
-( cd opt/kde/lib ; rm -rf libartsflow_idl.so.1 )
-( cd opt/kde/lib ; ln -sf libartsflow_idl.so.1.0.0 libartsflow_idl.so.1 )
-( cd opt/kde/lib ; rm -rf libartswavplayobject.so )
-( cd opt/kde/lib ; ln -sf libartswavplayobject.so.0.0.0 libartswavplayobject.so )
-( cd opt/kde/lib ; rm -rf libartswavplayobject.so.0 )
-( cd opt/kde/lib ; ln -sf libartswavplayobject.so.0.0.0 libartswavplayobject.so.0 )
-( cd opt/kde/lib ; rm -rf libkmedia2.so )
-( cd opt/kde/lib ; ln -sf libkmedia2.so.1.0.0 libkmedia2.so )
-( cd opt/kde/lib ; rm -rf libkmedia2.so.1 )
-( cd opt/kde/lib ; ln -sf libkmedia2.so.1.0.0 libkmedia2.so.1 )
-( cd opt/kde/lib ; rm -rf libkmedia2_idl.so )
-( cd opt/kde/lib ; ln -sf libkmedia2_idl.so.1.0.0 libkmedia2_idl.so )
-( cd opt/kde/lib ; rm -rf libkmedia2_idl.so.1 )
-( cd opt/kde/lib ; ln -sf libkmedia2_idl.so.1.0.0 libkmedia2_idl.so.1 )
-( cd opt/kde/lib ; rm -rf libmcop.so )
-( cd opt/kde/lib ; ln -sf libmcop.so.1.0.0 libmcop.so )
-( cd opt/kde/lib ; rm -rf libmcop.so.1 )
-( cd opt/kde/lib ; ln -sf libmcop.so.1.0.0 libmcop.so.1 )
 ( cd opt/kde/lib ; rm -rf libmcop_mt.so )
 ( cd opt/kde/lib ; ln -sf libmcop_mt.so.1.0.0 libmcop_mt.so )
+( cd opt/kde/lib ; rm -rf libmcop.so.1 )
+( cd opt/kde/lib ; ln -sf libmcop.so.1.0.0 libmcop.so.1 )
+( cd opt/kde/lib ; rm -rf libgmcop.so.1 )
+( cd opt/kde/lib ; ln -sf libgmcop.so.1.0.0 libgmcop.so.1 )
+( cd opt/kde/lib ; rm -rf libartsdsp_st.so )
+( cd opt/kde/lib ; ln -sf libartsdsp_st.so.0.0.0 libartsdsp_st.so )
+( cd opt/kde/lib ; rm -rf libkmedia2_idl.so )
+( cd opt/kde/lib ; ln -sf libkmedia2_idl.so.1.0.0 libkmedia2_idl.so )
+( cd opt/kde/lib ; rm -rf libsoundserver_idl.so.1 )
+( cd opt/kde/lib ; ln -sf libsoundserver_idl.so.1.0.0 libsoundserver_idl.so.1 )
+( cd opt/kde/lib ; rm -rf libartsflow_idl.so )
+( cd opt/kde/lib ; ln -sf libartsflow_idl.so.1.0.0 libartsflow_idl.so )
+( cd opt/kde/lib ; rm -rf libartsc.so.0 )
+( cd opt/kde/lib ; ln -sf libartsc.so.0.0.0 libartsc.so.0 )
+( cd opt/kde/lib ; rm -rf libartscbackend.so )
+( cd opt/kde/lib ; ln -sf libartscbackend.so.0.0.0 libartscbackend.so )
+( cd opt/kde/lib ; rm -rf libartsgslplayobject.so.0 )
+( cd opt/kde/lib ; ln -sf libartsgslplayobject.so.0.0.0 libartsgslplayobject.so.0 )
+( cd opt/kde/lib ; rm -rf libartsc.so )
+( cd opt/kde/lib ; ln -sf libartsc.so.0.0.0 libartsc.so )
+( cd opt/kde/lib ; rm -rf libartsflow_idl.so.1 )
+( cd opt/kde/lib ; ln -sf libartsflow_idl.so.1.0.0 libartsflow_idl.so.1 )
+( cd opt/kde/lib ; rm -rf libartsdsp.so )
+( cd opt/kde/lib ; ln -sf libartsdsp.so.0.0.0 libartsdsp.so )
 ( cd opt/kde/lib ; rm -rf libmcop_mt.so.1 )
 ( cd opt/kde/lib ; ln -sf libmcop_mt.so.1.0.0 libmcop_mt.so.1 )
 ( cd opt/kde/lib ; rm -rf libqtmcop.so )
 ( cd opt/kde/lib ; ln -sf libqtmcop.so.1.0.0 libqtmcop.so )
-( cd opt/kde/lib ; rm -rf libqtmcop.so.1 )
-( cd opt/kde/lib ; ln -sf libqtmcop.so.1.0.0 libqtmcop.so.1 )
-( cd opt/kde/lib ; rm -rf libsoundserver_idl.so )
-( cd opt/kde/lib ; ln -sf libsoundserver_idl.so.1.0.0 libsoundserver_idl.so )
-( cd opt/kde/lib ; rm -rf libsoundserver_idl.so.1 )
-( cd opt/kde/lib ; ln -sf libsoundserver_idl.so.1.0.0 libsoundserver_idl.so.1 )
 ( cd opt/kde/lib ; rm -rf libx11globalcomm.so )
 ( cd opt/kde/lib ; ln -sf libx11globalcomm.so.1.0.0 libx11globalcomm.so )
+( cd opt/kde/lib ; rm -rf libkmedia2_idl.so.1 )
+( cd opt/kde/lib ; ln -sf libkmedia2_idl.so.1.0.0 libkmedia2_idl.so.1 )
+( cd opt/kde/lib ; rm -rf libartsgslplayobject.so )
+( cd opt/kde/lib ; ln -sf libartsgslplayobject.so.0.0.0 libartsgslplayobject.so )
+( cd opt/kde/lib ; rm -rf libartswavplayobject.so )
+( cd opt/kde/lib ; ln -sf libartswavplayobject.so.0.0.0 libartswavplayobject.so )
+( cd opt/kde/lib ; rm -rf libkmedia2.so.1 )
+( cd opt/kde/lib ; ln -sf libkmedia2.so.1.0.0 libkmedia2.so.1 )
 ( cd opt/kde/lib ; rm -rf libx11globalcomm.so.1 )
 ( cd opt/kde/lib ; ln -sf libx11globalcomm.so.1.0.0 libx11globalcomm.so.1 )
+( cd opt/kde/lib ; rm -rf libartswavplayobject.so.0 )
+( cd opt/kde/lib ; ln -sf libartswavplayobject.so.0.0.0 libartswavplayobject.so.0 )
+( cd opt/kde/lib ; rm -rf libkmedia2.so )
+( cd opt/kde/lib ; ln -sf libkmedia2.so.1.0.0 libkmedia2.so )
+( cd opt/kde/lib ; rm -rf libqtmcop.so.1 )
+( cd opt/kde/lib ; ln -sf libqtmcop.so.1.0.0 libqtmcop.so.1 )
+( cd opt/kde/lib ; rm -rf libartsdsp_st.so.0 )
+( cd opt/kde/lib ; ln -sf libartsdsp_st.so.0.0.0 libartsdsp_st.so.0 )
